# KappaSchedules

[![publish](https://github.com/BenediktAlkin/KappaSchedules/actions/workflows/publish.yaml/badge.svg)](https://github.com/BenediktAlkin/KappaSchedules/actions/workflows/publish.yaml)
